```
Usage: vcd nsxt register [OPTIONS] <nsxt-name>

Options:
  -U, --url [url]            https://<FQDN or IP address> of NSX-T host
                             [required]
  -u, --user [username]      NSX-T admin user name  [required]
  -p, --password [password]  NSX-T admin password  [required]
  -d, --desc [description]   description of NSX-T manager
  -h, --help                 Show this message and exit.

```
